# oplus

## Installation

    pip install git+http://git@github.com/Openergy/oplus.git

## What is it
A python package for working with Energy Plus

## Releases

*(M): major, (m): minor, (p): patch*


